==> mx-conky_19.4.tar.xz: mx-conky-19.4/translations/mx-conky_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="45"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Programmet giver mulighed for detaljerede ændringer til den aktive conky. Den supplementerer Conky-håndtering, som bør bruges til grundlæggende indstillinger.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Kør</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Conky-navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Conky-håndtering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Træk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>For at tilpasse størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+venstreklik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>For at flytte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+højreklik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>BEMÆRK: ændringer huskes kun for den nuværende session</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Skrivebord 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Alle skriveborde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Forkortet navn, f.eks. Ti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Måned</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Forkortet navn, f.eks. Okt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Farver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="830"/>
        <location filename="../mainwindow.ui" line="942"/>
        <location filename="../mainwindow.ui" line="1054"/>
        <location filename="../mainwindow.ui" line="1169"/>
        <location filename="../mainwindow.ui" line="1284"/>
        <location filename="../mainwindow.ui" line="1399"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="893"/>
        <source>Color0 </source>
        <translation>Farve0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1005"/>
        <source>Color1 </source>
        <translation>Farve1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Color2 </source>
        <translation>Farve2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1232"/>
        <source>Color3 </source>
        <translation>Farve3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1347"/>
        <source>Color4 </source>
        <translation>Farve4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1481"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1484"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1539"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1542"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About MX Conky</source>
        <translation>Om MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Program med grafisk brugerflade til at konfigurerer Conky i MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>MX Conky Help</source>
        <translation>MX Conky-hjælp</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Select Conky Manager config file</source>
        <translation>Vælg konfigurationsfil til Conky-håndtering</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Opdatering af Conky-data</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>MX Conky-datasættet er blevet opdateret. &lt;p&gt;&lt;p&gt;                                  Kopiér fra mappen hvor den findes &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   hvad end du vil have som din din skjulte conky-hjemme &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Pas på du ikke overskriver conkies som du har ændret.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <location filename="../main.cpp" line="124"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Kunne ikke finde conky-manager, installer den venligst inden mx-conky køres</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="125"/>
        <source>No file was selected, quiting program</source>
        <translation>Der blev ikke valgt nogen fil, afslutter programmet</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <source>You must run this program as normal user</source>
        <translation>Du skal køre programmet som en normal bruger</translation>
    </message>
</context>
</TS>

==> mx-conky_21.7.tar.xz: mx-conky-21.7/translations/mx-conky_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="49"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Programmet giver mulighed for detaljerede ændringer til den aktive conky. Den supplementerer Conky-håndtering, som bør bruges til grundlæggende indstillinger.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Kør</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Conky-navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Conky-håndtering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Træk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>For at tilpasse størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+venstreklik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>For at flytte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+højreklik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>BEMÆRK: ændringer huskes kun for den nuværende session</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Skrivebord 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Alle skriveborde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Forkortet navn, f.eks. Ti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Måned</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Forkortet navn, f.eks. Okt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Farver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <location filename="../mainwindow.ui" line="948"/>
        <location filename="../mainwindow.ui" line="1063"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1299"/>
        <location filename="../mainwindow.ui" line="1417"/>
        <location filename="../mainwindow.ui" line="1532"/>
        <location filename="../mainwindow.ui" line="1647"/>
        <location filename="../mainwindow.ui" line="1762"/>
        <location filename="../mainwindow.ui" line="1877"/>
        <location filename="../mainwindow.ui" line="1992"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>Color0 </source>
        <translation>Farve0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>Color1 </source>
        <translation>Farve1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Color2 </source>
        <translation>Farve2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1244"/>
        <source>Color3 </source>
        <translation>Farve3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1362"/>
        <source>Color4 </source>
        <translation>Farve4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1480"/>
        <source>Color5</source>
        <translation type="unfinished">Farve4 {5?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1595"/>
        <source>Color6</source>
        <translation type="unfinished">Farve4 {6?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Color7</source>
        <translation type="unfinished">Farve4 {7?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1825"/>
        <source>Color8</source>
        <translation type="unfinished">Farve4 {8?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1940"/>
        <source>Color9</source>
        <translation type="unfinished">Farve4 {9?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2048"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2051"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2058"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2074"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2077"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2132"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2135"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2142"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>About MX Conky</source>
        <translation>Om MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Program med grafisk brugerflade til at konfigurerer Conky i MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>MX Conky Help</source>
        <translation>MX Conky-hjælp</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="57"/>
        <location filename="../mainwindow.cpp" line="690"/>
        <source>Select Conky Manager config file</source>
        <translation>Vælg konfigurationsfil til Conky-håndtering</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Opdatering af Conky-data</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>MX Conky-datasættet er blevet opdateret. &lt;p&gt;&lt;p&gt;                                  Kopiér fra mappen hvor den findes &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   hvad end du vil have som din din skjulte conky-hjemme &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Pas på du ikke overskriver conkies som du har ændret.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <location filename="../main.cpp" line="135"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Kunne ikke finde conky-manager, installer den venligst inden mx-conky køres</translation>
    </message>
    <message>
        <source>No file was selected, quiting program</source>
        <translation type="vanished">Der blev ikke valgt nogen fil, afslutter programmet</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <source>You must run this program as normal user</source>
        <translation>Du skal køre programmet som en normal bruger</translation>
    </message>
</context>
</TS>
